@@ -1,10 +1,10 @@
-__version_info__ = ('1', '11', '0')
+__version_info__ = ('1', '11', '1')
 __version__ = '.'.join(__version_info__)
 
 from .wrappers import (ObjectProxy, CallableObjectProxy, FunctionWrapper,
-        BoundFunctionWrapper, WeakFunctionProxy, resolve_path, apply_patch,
-        wrap_object, wrap_object_attribute, function_wrapper,
-        wrap_function_wrapper, patch_function_wrapper,
+        BoundFunctionWrapper, WeakFunctionProxy, PartialCallableObjectProxy,
+        resolve_path, apply_patch, wrap_object, wrap_object_attribute,
+        function_wrapper, wrap_function_wrapper, patch_function_wrapper,
         transient_function_wrapper)
 
 from .decorators import (adapter_factory, AdapterFactory, decorator,
